==> httpx-0.8.0-py2.py3-none-any.whl: httpx/__init__.py <==
from .__version__ import __description__, __title__, __version__
from .api import delete, get, head, options, patch, post, put, request
from .auth import BasicAuth, DigestAuth
from .client import Client
from .concurrency.asyncio import AsyncioBackend
from .concurrency.base import (
    BaseBackgroundManager,
    BasePoolSemaphore,
    BaseSocketStream,
    ConcurrencyBackend,
)
from .config import (
    USER_AGENT,
    CertTypes,
    HTTPVersionConfig,
    HTTPVersionTypes,
    PoolLimits,
    SSLConfig,
    TimeoutConfig,
    TimeoutTypes,
    VerifyTypes,
)
from .dispatch.base import Dispatcher
from .dispatch.connection import HTTPConnection
from .dispatch.connection_pool import ConnectionPool
from .dispatch.proxy_http import HTTPProxy, HTTPProxyMode
from .exceptions import (
    ConnectTimeout,
    CookieConflict,
    DecodingError,
    HTTPError,
    InvalidURL,
    NotRedirectResponse,
    PoolTimeout,
    ProtocolError,
    ProxyError,
    ReadTimeout,
    RedirectBodyUnavailable,
    RedirectLoop,
    ResponseClosed,
    ResponseNotRead,
    StreamConsumed,
    Timeout,
    TooManyRedirects,
    WriteTimeout,
)
from .models import (
    URL,
    AuthTypes,
    Cookies,
    CookieTypes,
    Headers,
    HeaderTypes,
    Origin,
    QueryParams,
    QueryParamTypes,
    Request,
    RequestData,
    RequestFiles,
    Response,
    ResponseContent,
    URLTypes,
)
from .status_codes import StatusCode, codes

__all__ = [
    "__description__",
    "__title__",
    "__version__",
    "delete",
    "get",
    "head",
    "options",
    "patch",
    "post",
    "patch",
    "put",
    "request",
    "BasicAuth",
    "Client",
    "DigestAuth",
    "AsyncioBackend",
    "USER_AGENT",
    "CertTypes",
    "PoolLimits",
    "SSLConfig",
    "TimeoutConfig",
    "VerifyTypes",
    "HTTPConnection",
    "BasePoolSemaphore",
    "BaseBackgroundManager",
    "ConnectionPool",
    "HTTPProxy",
    "HTTPProxyMode",
    "ConnectTimeout",
    "CookieConflict",
    "DecodingError",
    "HTTPError",
    "InvalidURL",
    "NotRedirectResponse",
    "PoolTimeout",
    "ProtocolError",
    "ReadTimeout",
    "RedirectBodyUnavailable",
    "RedirectLoop",
    "ResponseClosed",
    "ResponseNotRead",
    "StreamConsumed",
    "ProxyError",
    "Timeout",
    "TooManyRedirects",
    "WriteTimeout",
    "BaseSocketStream",
    "ConcurrencyBackend",
    "Dispatcher",
    "URL",
    "URLTypes",
    "StatusCode",
    "codes",
    "TimeoutTypes",
    "HTTPVersionTypes",
    "HTTPVersionConfig",
    "AuthTypes",
    "Cookies",
    "CookieTypes",
    "Headers",
    "HeaderTypes",
    "Origin",
    "QueryParams",
    "QueryParamTypes",
    "Request",
    "RequestData",
    "Response",
    "ResponseContent",
    "RequestFiles",
    "DigestAuth",
]

==> httpx-0.10.1-py2.py3-none-any.whl: httpx/__init__.py <==
from .__version__ import __description__, __title__, __version__
from .api import delete, get, head, options, patch, post, put, request, stream
from .auth import BasicAuth, DigestAuth
from .client import AsyncClient, Client
from .config import TimeoutConfig  # For 0.8 backwards compat.
from .config import PoolLimits, Timeout
from .dispatch.proxy_http import HTTPProxy, HTTPProxyMode
from .exceptions import (
    ConnectionClosed,
    ConnectTimeout,
    CookieConflict,
    DecodingError,
    HTTPError,
    InvalidURL,
    NotRedirectResponse,
    PoolTimeout,
    ProtocolError,
    ProxyError,
    ReadTimeout,
    RedirectBodyUnavailable,
    RedirectLoop,
    ResponseClosed,
    ResponseNotRead,
    StreamConsumed,
    TimeoutException,
    TooManyRedirects,
    WriteTimeout,
)
from .models import URL, Cookies, Headers, Origin, QueryParams, Request, Response
from .status_codes import StatusCode, codes

__all__ = [
    "__description__",
    "__title__",
    "__version__",
    "delete",
    "get",
    "head",
    "options",
    "patch",
    "post",
    "patch",
    "put",
    "request",
    "stream",
    "codes",
    "AsyncClient",
    "BasicAuth",
    "Client",
    "DigestAuth",
    "PoolLimits",
    "Timeout",
    "TimeoutConfig",  # For 0.8 backwards compat.
    "HTTPProxy",
    "HTTPProxyMode",  # For 0.8 backwards compat.
    "ConnectTimeout",
    "CookieConflict",
    "ConnectionClosed",
    "DecodingError",
    "HTTPError",
    "InvalidURL",
    "NotRedirectResponse",
    "PoolTimeout",
    "ProtocolError",
    "ReadTimeout",
    "RedirectBodyUnavailable",
    "RedirectLoop",
    "ResponseClosed",
    "ResponseNotRead",
    "StreamConsumed",
    "ProxyError",
    "TooManyRedirects",
    "WriteTimeout",
    "URL",
    "StatusCode",
    "Cookies",
    "Headers",
    "Origin",
    "QueryParams",
    "Request",
    "TimeoutException",
    "Response",
    "DigestAuth",
]
